aboutsummaryrefslogtreecommitdiffstats
path: root/tools/search_exa.sh
diff options
context:
space:
mode:
authorsigoden <sigoden@gmail.com>2024-07-17 09:23:52 +0800
committerGitHub <noreply@github.com>2024-07-17 09:23:52 +0800
commit2ee24731dc39985c5ed2014dc38edf44033af51d (patch)
tree936e606bcce12db94f3e61369e4b61a340084754 /tools/search_exa.sh
parenta4087408a27eeeb15ef2b6e193b16a6848759668 (diff)
downloadllm-functions-docker-2ee24731dc39985c5ed2014dc38edf44033af51d.tar.gz
refactor: search tools (#76)
Diffstat (limited to 'tools/search_exa.sh')
-rwxr-xr-xtools/search_exa.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/search_exa.sh b/tools/search_exa.sh
index ccb14cf..f14d342 100755
--- a/tools/search_exa.sh
+++ b/tools/search_exa.sh
@@ -5,7 +5,7 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env EXA_API_KEY! The api key
# @env EXA_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {
@@ -15,7 +15,7 @@ main() {
-d '
{
"query": "'"$argc_query"'",
- "numResults": '"$EXA_MAX_RESULTS"',
+ "numResults": '"$SEARCH_MAX_RESULTS"',
"type": "keyword",
"contents": {
"text": {
@@ -23,7 +23,7 @@ main() {
}
}
}' | \
- jq '[.results[] | {title: .title, url: .url, text: .text}]' \
+ jq '[.results[] | {link: .url, title: .title, snippet: .text}]' \
>> "$LLM_OUTPUT"
}
@@ -5,7 +5,7 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env EXA_API_KEY! The api key
-# @env EXA_MAX_RESULTS=5 The max results to return.
+# @env SEARCH_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {